<div id="values_block">
    <select id="dj_auth_filter_values" name="filter_values" size="10" multiple="multiple">
        {% for option in option_list %}
            {% if option.0 in selected %}
                <option value="{{ option.0 }}" selected="selected">{{ option.1 }}</option>
            {% else %}
                <option value="{{ option.0 }}">{{ option.1 }}</option>
            {% endif %}
        {% endfor %}
    </select>
</div>
