# -*- coding: utf-8 -*-
# Generated by Django 1.9.6 on 2016-07-29 12:48
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('contenttypes', '0002_remove_content_type_name'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='ObjectFilter',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('filter_type', models.SmallIntegerField(choices=[(0, 'Filter'), (1, 'Exclude')], verbose_name='Filter Type')),
                ('filter_values', models.CharField(blank=True, max_length=250, null=True, verbose_name='Values')),
                ('content_type', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='djauth_objectfilter_content_type', to='contenttypes.ContentType', verbose_name='Class')),
                ('users', models.ManyToManyField(related_name='djauth_objectfilter_users', to=settings.AUTH_USER_MODEL, verbose_name='User')),
            ],
            options={
                'verbose_name': 'Data filter',
                'verbose_name_plural': 'Data filter',
            },
        ),
    ]
